@@ -11,6 +11,7 @@ from flask.json import jsonify
 from flask_restful import Api, Resource, abort
 from flask_restful.reqparse import RequestParser
 
+from phootonics_controller.base_controllers.config import WL_INCREMENT
 from phootonics_controller.base_controllers.main_controller import MainController, AlreadyScanningException, \
     ControllerNotReady
 import logging
@@ -57,6 +58,9 @@ scan_post_parser.add_argument('positions', type=_pos_parser, required=True,
                               action='append',
                               help='list of (x, y) positions, example [(0.0, 0.0), (1.0, 0.0), ...]',
                               location=['json'])
+scan_post_parser.add_argument('wl_step', type=float, required=False,
+                              location=['json'],
+                              default=WL_INCREMENT)
 
 
 class ScanStart(ControllerResource):
@@ -66,7 +70,7 @@ class ScanStart(ControllerResource):
         if self.controller.is_scan_command_running():
             abort(403, message='scan command already running')
         try:
-            self.controller.start_scan(positions=args.positions)
+            self.controller.start_scan(positions=args.positions, wl_step=args.wl_step)
         except AlreadyScanningException:
             abort(403, message='scan command already running')
         except ControllerNotReady:
