@@ -30,17 +30,17 @@ configuration_dictionary = {
                                  'pulsing_mode': 'internal', 'applied_voltage': 17.2}, 'temperature_setpoint': 18}
 }
 
-WL_INCREMENT = 0.3
+WL_INCREMENT = 1.0
 
 
-def get_scanning_wavelengths():
+def get_scanning_wavelengths(wl_step=WL_INCREMENT):
     intervals = [configuration_dictionary[CAVITY1_INDEX]['wavelength'],
                  configuration_dictionary[CAVITY2_INDEX]['wavelength'],
                  configuration_dictionary[CAVITY3_INDEX]['wavelength'],
                  configuration_dictionary[CAVITY4_INDEX]['wavelength']]
     min_wl = min(x[0] for x in intervals)
     max_wl = max(x[1] for x in intervals)
-    return numpy.arange(min_wl, max_wl, WL_INCREMENT).tolist()
+    return numpy.arange(min_wl, max_wl, wl_step).tolist()
 
 
 if __name__ == '__main__':
