@@ -92,6 +92,7 @@ class ScanCommand:
     def execute(self):
         try:
             if not self._controller.testMode or self._testWithMocks:
+                self._controller.stop_all_pulsing()
                 self._controller.move_to_cavity_1()
                 self._controller.get_active_cavity().activate_s2()
                 for wavelength in self.wavelengths:
@@ -140,6 +141,8 @@ class ScanCommand:
         except Exception as e:
             self.error = str(e)
             logger.exception(e)
+        finally:
+            self._controller.stop_all_pulsing()
 
     def stop(self):
         self.stopped.set()
@@ -291,6 +294,12 @@ class MainController:
         else:
             return MainController.NOT_READY
 
+    def stop_all_pulsing(self):
+        self.ec1.stop_pulsing()
+        self.ec2.stop_pulsing()
+        self.ec3.stop_pulsing()
+        self.ec4.stop_pulsing()
+
     def shutdown_all_systems(self, reset=False):
         try:
             self.stop_monitoring()
