@@ -90,7 +90,7 @@ class ECController(BaseController):
 
     def xc_ready_to_action(self):
         try:
-            if self._pulser_status == 2003 and self._tc_status == 4000 and self._stage_status == 3001 and self.is_temp_stable():
+            if self._pulser_status in [2003, 2004] and self._tc_status == 4000 and self._stage_status == 3001 and self.is_temp_stable():
                 return ECController.READY
             else:
                 return ECController.NOT_READY
