@@ -16,6 +16,8 @@ import requests
 
 import pandas
 
+from phootonics_controller.base_controllers.config import WL_INCREMENT
+
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
@@ -26,6 +28,7 @@ def scan():
     parser = ArgumentParser()
     parser.add_argument('-x', nargs='+', type=float)
     parser.add_argument('-y', nargs='+', type=float)
+    parser.add_argument('-wl_step', type=float, required=False, default=WL_INCREMENT)
     args=parser.parse_args()
     x_list = args.x
     y_list = args.y
@@ -39,7 +42,7 @@ def scan():
         parser.error('Scan command already running.')
 
     rsp = requests.post(PHOOTONICS_URL + '/scan/start',
-                        json={'positions': positions})
+                        json={'positions': positions, 'wl_step': args.wl_step})
     if not rsp.status_code == 200:
         print(rsp.json())
         rsp.raise_for_status()
